==> simsu-1.2.3-src.tar.bz2: simsu-1.2.3/translations/simsu_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="73"/>
        <location filename="../src/board.cpp" line="88"/>
        <source>Success</source>
        <translation>Επιτυχές</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Επιλέξτε γλώσσα εφαρμογής:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα Συστήματος&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλούμε επανεκκινήστε την εφαρμογή για να αλλάξει η γλώσσα.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <location filename="../src/pattern.h" line="56"/>
        <source>180° Rotational</source>
        <translation>Περιστροφικό 180°</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="57"/>
        <source>Full Rotational</source>
        <translation>Πλήρες Περιστροφικό</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="58"/>
        <source>Horizontal</source>
        <translation>Οριζόντια</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="59"/>
        <source>Vertical</source>
        <translation>Καθέτα</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="60"/>
        <source>Horizontal &amp; Vertical</source>
        <translation>Οριζόντια και Κάθετα</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="61"/>
        <source>Diagonal</source>
        <translation>Διαγωνίως</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="62"/>
        <source>Anti-Diagonal</source>
        <translation>Διαγωνίως Αντίστροφα</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="63"/>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Διαγώνια &amp; Διαγωνίως Αντίστροφα</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="64"/>
        <source>Full Dihedral</source>
        <translation>Πλήρες Δίεδρος</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="65"/>
        <source>Random</source>
        <translation>Τυχαία</translation>
    </message>
    <message>
        <location filename="../src/pattern.h" line="66"/>
        <source>None</source>
        <translation>Καθόλου</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="71"/>
        <location filename="../src/window.cpp" line="301"/>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="89"/>
        <source>Pen</source>
        <translation>Στυλό</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>Pencil</source>
        <translation>Μολύβι</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Highlight</source>
        <translation>Επισήμανση</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="99"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="106"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>&amp;Game</source>
        <translation>&amp;Παρτίδα</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="144"/>
        <source>&amp;New</source>
        <translation>&amp;Νέα</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="144"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>&amp;Details</source>
        <translation>&amp;Λεπτομέρειες</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="147"/>
        <source>&amp;Quit</source>
        <translation>&amp;Έξοδος</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="147"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="149"/>
        <source>&amp;Move</source>
        <translation>&amp;Κίνηση</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="150"/>
        <source>&amp;Undo</source>
        <translation>&amp;Αναίρεση</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="150"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="152"/>
        <source>&amp;Redo</source>
        <translation>&amp;Επανάληψη</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="152"/>
        <source>Shift+Ctrl+Z</source>
        <translation>Shift+Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="155"/>
        <source>&amp;Check</source>
        <translation>&amp;Έλεγχος</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="155"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="158"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="159"/>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Αυτόματη Αλλαγή Λειτουργίας</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="163"/>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Προβολή Ευρύς Οθόνης</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>Application &amp;Language...</source>
        <translation>Γλώσσα &amp;Εφαρμογής...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="170"/>
        <location filename="../src/window.cpp" line="177"/>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>&amp;Controls</source>
        <translation>&amp;Χειρισμός</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="179"/>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="180"/>
        <source>About &amp;Qt</source>
        <translation>Σχετικά με το &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="218"/>
        <source>New Game</source>
        <translation>Νέο Παιχνίδι</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="235"/>
        <location filename="../src/window.cpp" line="275"/>
        <source>Dancing Links</source>
        <translation>Χορευτικοί Σύνδεσμοι</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="236"/>
        <location filename="../src/window.cpp" line="275"/>
        <source>Slice and Dice</source>
        <translation>Κόψε και Χώρισε</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="241"/>
        <source>Random</source>
        <translation>Τυχαία</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="249"/>
        <source>Symmetry:</source>
        <translation>Συμμετρία:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <source>Algorithm:</source>
        <translation>Αλγόριθμος:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <source>Seed:</source>
        <translation>Βάση γεννήτριας:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="278"/>
        <source>Details</source>
        <translation>Λεπτομέριες</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="278"/>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Συμμετρία:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Αλγόριθμος:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Βάση:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="286"/>
        <source>Controls</source>
        <translation>Χειρισμός</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="286"/>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Χειρισμός Ποντικιού:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Αριστερό Κλικ:&lt;/b&gt; Εναλλαγή αριθμού σε λειτουργία στυλό&lt;br&gt;&lt;b&gt;Δεξί κλικ:&lt;/b&gt; Εναλλαγή αριθμού σε λειτουργία μολυβιού &lt;br&gt;&lt;b&gt;Τροχός:&lt;/b&gt; Αλλαγή επιλεγμένου αριθμού&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Χειρισμός Πληκτρολογίου:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Βελάκια:&lt;/b&gt; Μετακίνηση επιλογής&lt;br&gt;&lt;b&gt;Αριθμητικά πλήκτρα:&lt;/b&gt; Αλλαγή αριθμού&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Εναλλαγή ανάμεσα λειτουργίες στυλό και μολυβιού&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Επισήμανση όλων των περιπτώσεων του επιλεγμένου αριθμού&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="300"/>
        <source>About Simsu</source>
        <translation>Σχετικά με το Simsu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="302"/>
        <source>A basic Sudoku game</source>
        <translation>Ένα βασικό παιχνίδι Σουντόκου</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="303"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="304"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Κυκλοφορεί υπό την άδεια χρήσης &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> simsu-1.3.9-src.tar.bz2: simsu-1.3.9/translations/simsu_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Επιτυχές</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Επιλέξτε γλώσσα εφαρμογής:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Γλώσσα Συστήματος&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Σημείωση</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Παρακαλούμε επανεκκινήστε την εφαρμογή για να αλλάξει η γλώσσα.</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <source>180° Rotational</source>
        <translation>Περιστροφικό 180°</translation>
    </message>
    <message>
        <source>Full Rotational</source>
        <translation>Πλήρες Περιστροφικό</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Οριζόντια</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Καθέτα</translation>
    </message>
    <message>
        <source>Horizontal &amp; Vertical</source>
        <translation>Οριζόντια και Κάθετα</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Διαγωνίως</translation>
    </message>
    <message>
        <source>Anti-Diagonal</source>
        <translation>Διαγωνίως Αντίστροφα</translation>
    </message>
    <message>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Διαγώνια &amp; Διαγωνίως Αντίστροφα</translation>
    </message>
    <message>
        <source>Full Dihedral</source>
        <translation>Πλήρες Δίεδρος</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Τυχαία</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Καθόλου</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Στυλό</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Μολύβι</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Επισήμανση</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Παρτίδα</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Νέα</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Λεπτομέρειες</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Έ&amp;ξοδος</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Κίνηση</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Αναίρεση</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Ε&amp;πανάληψη</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>Έλ&amp;εγχος</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ρυθμίσεις</translation>
    </message>
    <message>
        <source>&amp;Auto Switch Modes</source>
        <translation>&amp;Αυτόματη Αλλαγή Λειτουργίας</translation>
    </message>
    <message>
        <source>&amp;Widescreen Layout</source>
        <translation>&amp;Προβολή Ευρύς Οθόνης</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Γλώσσα &amp;Εφαρμογής...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Χειρισμός</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Σχετικά</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Σχετι&amp;κά με το Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Νέο Παιχνίδι</translation>
    </message>
    <message>
        <source>Dancing Links</source>
        <translation>Χορευτικοί Σύνδεσμοι</translation>
    </message>
    <message>
        <source>Slice and Dice</source>
        <translation>Κόψε και Χώρισε</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Τυχαία</translation>
    </message>
    <message>
        <source>Symmetry:</source>
        <translation>Συμμετρία:</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Αλγόριθμος:</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Βάση γεννήτριας:</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Λεπτομέριες</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Symmetry:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Συμμετρία:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Αλγόριθμος:&lt;/b&gt; %L2&lt;br&gt;&lt;b&gt;Βάση:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Χειρισμός</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Χειρισμός Ποντικιού:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Αριστερό Κλικ:&lt;/b&gt; Εναλλαγή αριθμού σε λειτουργία στυλό&lt;br&gt;&lt;b&gt;Δεξί κλικ:&lt;/b&gt; Εναλλαγή αριθμού σε λειτουργία μολυβιού &lt;br&gt;&lt;b&gt;Τροχός:&lt;/b&gt; Αλλαγή επιλεγμένου αριθμού&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Χειρισμός Πληκτρολογίου:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Βελάκια:&lt;/b&gt; Μετακίνηση επιλογής&lt;br&gt;&lt;b&gt;Αριθμητικά πλήκτρα:&lt;/b&gt; Αλλαγή αριθμού&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Εναλλαγή ανάμεσα λειτουργίες στυλό και μολυβιού&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Επισήμανση όλων των περιπτώσεων του επιλεγμένου αριθμού&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Simsu</source>
        <translation>Σχετικά με το Simsu</translation>
    </message>
    <message>
        <source>A basic Sudoku game</source>
        <translation>Βασικό παιχνίδι Σουντόκου</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Κυκλοφορεί υπό την άδεια χρήσης &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
